@@ -2,6 +2,7 @@
 
 from .categories import (Category, CategoriesCollection,
                          SubCategory, SubCategoriesCollection)
+from .geojson import GeoJsonROI
 from .rois import ROI, ROIsCollection, ROIsCollectionWithCategories
 from .rois_stephan_2020_pss import CallistoROIs, GanymedeROIs
 
@@ -16,4 +17,5 @@ __all__ = [
     'ROIsCollectionWithCategories',
     'CallistoROIs',
     'GanymedeROIs',
+    'GeoJsonROI',
 ]
