@@ -13,6 +13,7 @@ from .categories import (Category, CategoriesCollection,
                          SubCategory, SubCategoriesCollection)
 
 from ..projections import Equirectangular
+from ..trajectory import Trajectory
 
 
 class ROI(AbstractItem):
@@ -133,8 +134,10 @@ class ROI(AbstractItem):
 
         Parameters
         ----------
-        pts: np.array
-            List of geographic point(s): ``(lon_e, lat)`` or ``[(lon_e, lat), …]``
+        pts: np.array or trajectory.Trajectory
+            List of geographic point(s): ``(lon_e, lat)`` or ``[(lon_e, lat), …]``.
+            If a :py:obj:`Trajectory` is provided, the intersection
+            will be performed on the its sub-observer points.
 
         Returns
         -------
@@ -142,11 +145,20 @@ class ROI(AbstractItem):
             Return ``TRUE`` if the point is inside the pixel corners, and
             ``FALSE`` overwise.
 
-        WARNING
+        Warning
         -------
-        The data need to be projected on a sphere first
+        The data need to be projected on a sphere first.
+        Here we project the :py:obj:`ROI` on a Equirectangular
+        plane before doing the intersection.
+
+        Note
+        ----
+        If the point is on the edge of the contour it will be excluded.
 
         """
+        if isinstance(pts, Trajectory):
+            return self.contains(pts.sub_obs_pts[1:])
+
         if np.ndim(pts) == 1:
             return self.contains([pts])
 
